==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectAttribute.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectattribute_h
#define objectattribute_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_attribute {
  t_adms _adms;
  char* _name;
  int _name_isdefault : 1;
  char* _value;
  int _value_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_attribute_getuid (p_attribute myattribute);
win32_interface gboolean adms_attribute_cmp (p_attribute myattribute,p_attribute refattribute);
win32_interface p_attribute adms_attribute_new_1 (char* myname);
#define adms_attribute_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_attribute_free(item)\
{\
  free(item->_name);\
  free(item->_value);\
  free(item);\
}
win32_interface p_adms adms_attribute_new_impl (p_adms arguments[]);
win32_interface p_attribute adms_attribute_impl (void* member);
#define adms_attribute(member) ((p_attribute) (member))
#define adms_attribute_new adms_attribute_new_1
#define adms_attribute_isdefault_name(attribute) (adms_attribute(attribute)->_name_isdefault)
#define adms_attribute_valueof_name(attribute) (adms_attribute(attribute)->_name)
#define adms_attribute_isdefault_value(attribute) (adms_attribute(attribute)->_value_isdefault)
#define adms_attribute_valueof_value(attribute) (adms_attribute(attribute)->_value)
#define adms_attribute_valueof_adms(attribute) ((p_adms)attribute)
#define adms_attribute_valueto_name(a,b) ((p_attribute)a)->_name=(b)
win32_interface void adms_attribute_valueto_name_impl (p_attribute myattribute,char* _name);
#define adms_attribute_valueto_value(a,b) ((p_attribute)a)->_value=(b)
win32_interface void adms_attribute_valueto_value_impl (p_attribute myattribute,char* _value);
#endif /* objectattribute_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectAttribute.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectattribute_h
#define objectattribute_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_attribute {
  t_adms _adms;
  p_quark _name;
  int _name_isdefault : 1;
  p_adms _value;
  int _value_isdefault : 1;
};
#include <admsObject/objectQuark.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_attribute_uid (p_attribute myattribute);
win32_interface int adms_attribute_cmp (p_attribute myattribute,p_attribute refattribute);
win32_interface p_attribute adms_attribute_new(p_quark myname);
win32_interface p_adms adms_attribute_new_impl (p_adms arguments[]);
#define adms_attribute(member) ((p_attribute) (member))
#define adms_attribute_isdefault_name(attribute) (adms_attribute(attribute)->_name_isdefault)
#define adms_attribute_valueof_name(attribute) (adms_attribute(attribute)->_name)
#define adms_attribute_isdefault_value(attribute) (adms_attribute(attribute)->_value_isdefault)
#define adms_attribute_valueof_value(attribute) (adms_attribute(attribute)->_value)
#define adms_attribute_valueof_adms(attribute) ((p_adms)attribute)
win32_interface inline void adms_attribute_valueto_name (p_attribute myattribute,p_quark _name);
win32_interface inline void adms_attribute_valueto_value (p_attribute myattribute,p_adms _value);
win32_interface inline void adms_attribute_free(p_attribute myattribute);
#endif /* objectattribute_h */
